@@ -45,10 +45,11 @@ Une fois configuré, vous n'avez plus rien à faire, AutoFreeWifi procèdera \n\
 
         hLayout3 = QtGui.QHBoxLayout()
         
-        buttonOK = QtGui.QDialogButtonBox()
-        buttonOK.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
+        buttonOK = QtGui.QPushButton("Valider")
+        buttonCancel = QtGui.QPushButton("Annuler")
         
         hLayout3.addWidget(buttonOK)
+        hLayout3.addWidget(buttonCancel)
 
         vLayout = QtGui.QVBoxLayout()
         vLayout.addLayout(hHelpLayout)
@@ -60,8 +61,8 @@ Une fois configuré, vous n'avez plus rien à faire, AutoFreeWifi procèdera \n\
         self.mainframe.setLayout(vLayout)
         self.setCentralWidget(self.mainframe)
 
-        QtCore.QObject.connect(buttonOK, QtCore.SIGNAL("accepted()"), self.accept)
-        QtCore.QObject.connect(buttonOK, QtCore.SIGNAL("rejected()"), self.reject)
+        QtCore.QObject.connect(buttonOK, QtCore.SIGNAL("clicked()"), self.accept)
+        QtCore.QObject.connect(buttonCancel, QtCore.SIGNAL("clicked()"), self.reject)
         
     def accept(self):
         login = self.login.text()
